==> illumination_0.1.20081120-1.tar.gz: illumination-0.1.20081120/src/Lum/Dlg/ColorChooser.cpp <==
/*
  This source is part of the Illumination library
  Copyright (C) 2005  Tim Teulings

  This library is free software; you can redistribute it and/or
  modify it under the terms of the GNU Lesser General Public
  License as published by the Free Software Foundation; either
  version 2.1 of the License, or (at your option) any later version.

  This library is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  Lesser General Public License for more details.

  You should have received a copy of the GNU Lesser General Public
  License along with this library; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
*/

#include <Lum/Dlg/ColorChooser.h>

#include <Lum/Base/L10N.h>

#include <Lum/ButtonRow.h>
#include <Lum/ColorView.h>
#include <Lum/Panel.h>
#include <Lum/RGBControl.h>
#include <Lum/Space.h>

namespace Lum {
  namespace Dlg {
    ColorChooser::ColorChooser(Model::Color* color)
    : color(color),
      okAction(new Lum::Model::Action)
    {
      AttachModel(okAction);
      AttachModel(GetClosedAction());
    }

    ColorChooser::~ColorChooser()
    {
      // no code
    }

    void ColorChooser::PreInit()
    {
      ButtonRow   *row;
      ColorView   *colorView;
      Panel       *vPanel,*hPanel;
      RGBControl  *rgb;

      vPanel=new Lum::VPanel();
      vPanel->SetFlex(true,false);

      hPanel=new Lum::HPanel();
      hPanel->SetFlex(true,false);

      colorView=new Lum::ColorView();
      colorView->SetFlex(true,true);
      colorView->SetModel(color);
      hPanel->Add(colorView);

      hPanel->Add(new HSpace());

      rgb=new Lum::RGBControl();
      rgb->SetModel(color);
      hPanel->Add(rgb);

      vPanel->Add(hPanel);

      vPanel->Add(new VSpace());

      row=Lum::ButtonRow::CreateOkCancel(okAction,GetClosedAction());
      row->SetFlex(true,false);
      vPanel->Add(row);

      SetMain(vPanel);

      Dialog::PreInit();
    }

    void ColorChooser::Resync(Lum::Base::Model* model, const Lum::Base::ResyncMsg& msg)
    {
      if (model==okAction && okAction->IsFinished()) {
        color->Save();
        Exit();
      }
      else if (model==GetClosedAction() && GetClosedAction()->IsFinished()) {
        Exit();
      }
      else {
        Dialog::Resync(model,msg);
      }
    }

    void ColorChooser::GetColor(OS::Window* parent,
                                Model::Color* color)
    {
      assert(color!=NULL);

      ColorChooser *dlg;

      color->Push();

      dlg=new ColorChooser(color);
      dlg->SetParent(parent);
      dlg->SetTitle(L""/*caption*/);

      if (dlg->Open()) {
        dlg->EventLoop();
        dlg->Close();
      }

      delete dlg;

      color->Pop();
    }
  }
}

==> illumination_0.1.20081201-1.tar.gz: illumination-0.1.20081201/src/Lum/Dlg/ColorChooser.cpp <==
/*
  This source is part of the Illumination library
  Copyright (C) 2005  Tim Teulings

  This library is free software; you can redistribute it and/or
  modify it under the terms of the GNU Lesser General Public
  License as published by the Free Software Foundation; either
  version 2.1 of the License, or (at your option) any later version.

  This library is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  Lesser General Public License for more details.

  You should have received a copy of the GNU Lesser General Public
  License along with this library; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
*/

#include <Lum/Dlg/ColorChooser.h>

#include <Lum/Base/L10N.h>

#include <Lum/ButtonRow.h>
#include <Lum/ColorView.h>
#include <Lum/Panel.h>
#include <Lum/RGBControl.h>
#include <Lum/Space.h>

namespace Lum {
  namespace Dlg {
    ColorChooser::ColorChooser(Model::Color* color)
    : color(color),
      okAction(new Lum::Model::Action)
    {
      Observe(okAction);
      Observe(GetClosedAction());
    }

    ColorChooser::~ColorChooser()
    {
      // no code
    }

    void ColorChooser::PreInit()
    {
      ButtonRow   *row;
      ColorView   *colorView;
      Panel       *vPanel,*hPanel;
      RGBControl  *rgb;

      vPanel=new Lum::VPanel();
      vPanel->SetFlex(true,false);

      hPanel=new Lum::HPanel();
      hPanel->SetFlex(true,false);

      colorView=new Lum::ColorView();
      colorView->SetFlex(true,true);
      colorView->SetModel(color);
      hPanel->Add(colorView);

      hPanel->Add(new HSpace());

      rgb=new Lum::RGBControl();
      rgb->SetModel(color);
      hPanel->Add(rgb);

      vPanel->Add(hPanel);

      vPanel->Add(new VSpace());

      row=Lum::ButtonRow::CreateOkCancel(okAction,GetClosedAction());
      row->SetFlex(true,false);
      vPanel->Add(row);

      SetMain(vPanel);

      Dialog::PreInit();
    }

    void ColorChooser::Resync(Lum::Base::Model* model, const Lum::Base::ResyncMsg& msg)
    {
      if (model==okAction && okAction->IsFinished()) {
        color->Save();
        Exit();
      }
      else if (model==GetClosedAction() && GetClosedAction()->IsFinished()) {
        Exit();
      }
      else {
        Dialog::Resync(model,msg);
      }
    }

    void ColorChooser::GetColor(OS::Window* parent,
                                Model::Color* color)
    {
      assert(color!=NULL);

      ColorChooser *dlg;

      color->Push();

      dlg=new ColorChooser(color);
      dlg->SetParent(parent);
      dlg->SetTitle(L""/*caption*/);

      if (dlg->Open()) {
        dlg->EventLoop();
        dlg->Close();
      }

      delete dlg;

      color->Pop();
    }
  }
}
